| Title: | Preparer of Main Scientific References for Automatic Insertion in Academic Papers |
|---|---|
| Description: | Generates a file, containing the main scientific references, prepared to be automatically inserted into an academic paper. The articles present in the list are chosen from the main references generated, by function principal_lister(), of the package 'bibliorefer'. The generated file contains the list of metadata of the principal references in 'BibTex' format. Massimo Aria, Corrado Cuccurullo. (2017) <doi:10.1016/j.joi.2017.08.007>. Caibo Zhou, Wenyan Song. (2021) <doi:10.1016/j.jclepro.2021.126943>. Hamid Derviş. (2019) <doi:10.5530/jscires.8.3.32>. |
| Authors: | Márcio Eustáquio [cre], Márcio Eustáquio [aut] |
| Maintainer: | Márcio Eustáquio <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.3 |
| Built: | 2026-05-25 08:10:09 UTC |
| Source: | https://github.com/cran/gerefer |
The article_bib function prepares the metadata of the main scientific references to be automatically included in a scientific article. Initially, the user obtains the list of main references using the principal_lister function from the bibliorefer package. Then, read the articles, choose the ones you prefer, and display the positions of these articles in the input parameter, position_artic, of the article_bib function. The article_bib function internally calls the gerard_lister and bibtex_lister functions. The gerard_lister function separates and organizes the metadata, of each of the articles in the list chosen by the user, and stores them in a dataframe. Then, the bibtex_lister function is applied to the set of metadata organized in the dataframe and converts it to the BibTex style. The output of the article_bib function is the file with the .bib extension, containing the list of references in BibTex format, prepared to be automatically included in the reference list of a scientific paper.
article_bib( input_date, input_tam, position_artic, total_list, input_linkdateacess )article_bib( input_date, input_tam, position_artic, total_list, input_linkdateacess )
input_date |
is a dataframe with the scientific production database obtained of colection WoS, Scopus and others |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
position_artic |
is a parameter that shows the positions of the articles in the main list, obtained using package bibliorefer, chosen to be included in the reference list of a scientific paper. If part of the list is used, the set of articles is presented through a sequence or a concatenated set. If the complete list is used, the complete sequence is created |
total_list |
is the parameter that defines whether all articles from the main list, obtained using package bibliorefer, will be used or not. This parameter contains the logical values TRUE or FALSE. If the full list is used, the value is TRUE. Otherwise, if a part of the list is used, the value is FALSE |
input_linkdateacess |
is the parameter that shows the list of links and access dates of the chosen scientific articles |
This function returns a file with the .bib extension, containing the list of references in bibtex format, prepared to be automatically included in the reference list of a scientific paper.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example1.csv", package = "gerefer") input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- c(1,2,4,5,9,11,14,16,19,20) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 2 - Position article in initial sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example2.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- seq(1,10,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 3 - Position article in final sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example3.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- seq(11,20,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 4 - Position article total sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabela_acessototal.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- TRUE position_artic <- seq(1,20,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example1.csv", package = "gerefer") input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- c(1,2,4,5,9,11,14,16,19,20) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 2 - Position article in initial sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example2.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- seq(1,10,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 3 - Position article in final sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabarticle_example3.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- FALSE position_artic <- seq(11,20,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex # Example 4 - Position article total sequence # File of database file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") file_base <- system.file("extdata","tabela_acessototal.csv", package = "gerefer") # Parameters of the function input_date <- example_databaseart(file_db) input_tam <- 20 total_list <- TRUE position_artic <- seq(1,20,1) input_linkdateacess <- basede_linkdate(file_base) #Calls the function article_bib lister_bibtex <- article_bib(input_date, input_tam, position_artic, total_list, input_linkdateacess) lister_bibtex
The article_bibextra function prepares the metadata of the main scientific references to be automatically included in a scientific article. Initially, the user obtains the list of main references indicated and enters them into the standardized tabarticle_extra spreadsheet. The article_bibextra function internally calls the gerard_lister and bibtex_lister functions. The gerard_lister function separates and organizes the metadata of each article in the list selected by the user and stores it in a dataframe. The bibtex_lister function is then applied to the set of metadata organized in the dataframe and converts it to BibTex format. The output of the article_bibextra function is a file with the .bib extension, containing the list of references in BibTex format, prepared to be automatically included in the reference list of a scientific article.
article_bibextra(input_date, input_tam)article_bibextra(input_date, input_tam)
input_date |
is a dataframe with the scientific production database obtained of colection WoS, Scopus and others |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
This function returns a file with the .bib extension, containing the list of references in bibtex format, prepared to be automatically included in the reference list of a scientific paper.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example 1 # File of database file_db <- system.file("extdata","database_articleextra.csv", package = "gerefer") input_date <- example_database2(file_db) input_tam <- 8 #Calls the function article_bib lister_bibtex <- article_bibextra(input_date, input_tam) lister_bibtex# Example 1 # File of database file_db <- system.file("extdata","database_articleextra.csv", package = "gerefer") input_date <- example_database2(file_db) input_tam <- 8 #Calls the function article_bib lister_bibtex <- article_bibextra(input_date, input_tam) lister_bibtex
The basede_linkdate function reads a csv file containing the links and access dates of scientific articles, selected and represented by the sequence present in the position_artic parameter. The function returns a dataframe that will be used by the gerefer package.
basede_linkdate(path_date)basede_linkdate(path_date)
path_date |
is a directory path containing the csv file |
The function returns a table containing the links and access dates of the chosen scientific articles.
Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier
#Call the function of links and access data file_base <- system.file("extdata","tabarticle_example1.csv", package = "gerefer") dateacess_link <- basede_linkdate(file_base) dateacess_link#Call the function of links and access data file_base <- system.file("extdata","tabarticle_example1.csv", package = "gerefer") dateacess_link <- basede_linkdate(file_base) dateacess_link
The book_bib function prepares the metadata of books to be automatically included in a scientific article. The book_bib function internally calls two support functions. The output of the book_bib function is the file with the .bib extension, of the books in BibTex format, prepared to be automatically included in the reference list of a scientific article.
book_bib(input_date, input_tam)book_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a books |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
The output of the book_bib function is the file with the .bib extension, of the books in BibTex format, prepared to be automatically in the list of references of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","livro.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 5 #Calls the function book_bib booklister_bibtex <- book_bib(input_date, input_tam) booklister_bibtex# Example # File of database file_db <- system.file("extdata","livro.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 5 #Calls the function book_bib booklister_bibtex <- book_bib(input_date, input_tam) booklister_bibtex
The bookcap_bib function prepares the metadata of book chapters to be automatically included in a scientific article. The bookcap_bib function internally calls two support functions. The output of the bookcap_bib function is the file with the .bib extension, of the book chapters in BibTex format, prepared to be automatically included in the reference list of a scientific article.
bookcap_bib(input_date, input_tam)bookcap_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a book chapters |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
The output of the bookcap_bib function is the file with the .bib extension, of the book chapters in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","bookcap.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function bookcap_bib bookcaplister_bibtex <- bookcap_bib(input_date, input_tam) bookcaplister_bibtex# Example # File of database file_db <- system.file("extdata","bookcap.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function bookcap_bib bookcaplister_bibtex <- bookcap_bib(input_date, input_tam) bookcaplister_bibtex
The bookinst_bib function prepares the metadata of institutional books to be automatically included in a scientific article. The bookinst_bib function internally calls two support functions. The output of the bookinst_bib function is the file with the .bib extension of institutional books in BibTex format, prepared to be automatically included in the reference list of a scientific article.
bookinst_bib(input_date, input_tam)bookinst_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a institutional books |
input_tam |
is the length of the dataframe with the institutional books, obtained using package bibliorefer. |
The output of the bookinst_bib function is the file with the .bib extension of institutional books in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","compinst.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 5 #Calls the function bookcap_bib bookinstlister_bibtex <- bookinst_bib(input_date, input_tam) bookinstlister_bibtex# Example # File of database file_db <- system.file("extdata","compinst.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 5 #Calls the function bookcap_bib bookinstlister_bibtex <- bookinst_bib(input_date, input_tam) bookinstlister_bibtex
The bookinstsub_bib function prepares the metadata of institutional book chapters to be automatically included in a scientific article. The bookinstsub_bib function internally calls two support functions. The output of the bookinstsub_bib function is the file with the .bib extension of institutional book chapters in BibTex format, prepared to be automatically included in the reference list of a scientific article.
bookinstsub_bib(input_date, input_tam)bookinstsub_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a institutional books chapters. |
input_tam |
is the length of the dataframe with the institutional books chapters, obtained using package bibliorefer. |
The output of the bookinstsub_bib function is the file with the .bib extension of institutional book chapters in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","compinst2.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 6 #Calls the function bookinstsub_bib bookinstsublister_bibtex <- bookinstsub_bib(input_date, input_tam) bookinstsublister_bibtex# Example # File of database file_db <- system.file("extdata","compinst2.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 6 #Calls the function bookinstsub_bib bookinstsublister_bibtex <- bookinstsub_bib(input_date, input_tam) bookinstsublister_bibtex
The bookorg_bib function prepares the metadata of books with organizers to be automatically included in a scientific article. The bookorg_bib function internally calls two support functions. The output of the bookorg_bib function is the file with the .bib extension of books with organizers in BibTex format, prepared to be automatically included in the reference list of a scientific article.
bookorg_bib(input_date, input_tam)bookorg_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a book with organizers |
input_tam |
is the length of the dataframe with the book with organizers, obtained using package bibliorefer. |
The output of the bookorg_bib function is the file with the .bib extension of books with organizers in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","bookorg.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 9 #Calls the function bookorg_bib bookorglister_bibtex <- bookorg_bib(input_date, input_tam) bookorglister_bibtex# Example # File of database file_db <- system.file("extdata","bookorg.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 9 #Calls the function bookorg_bib bookorglister_bibtex <- bookorg_bib(input_date, input_tam) bookorglister_bibtex
The congresso_bib function prepares the metadata of the main conference articles to be automatically included in a scientific article. The congresso_bib function internally calls two support functions. The output of the congresso_bib function is the file with the .bib extension, containing the list of references of conference articles in BibTex format, prepared to be automatically included in the list of references of a scientific article.
congresso_bib(input_date, input_tam)congresso_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a monograph |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
The output of the congresso_bib function is the file with the .bib extension, containing the list of references of conference articles in BibTex format, prepared to be automatically included in the list of references of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","congresso.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 7 #Calls the function congresso_bib congressolister_bibtex <- congresso_bib(input_date, input_tam) congressolister_bibtex# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","congresso.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 7 #Calls the function congresso_bib congressolister_bibtex <- congresso_bib(input_date, input_tam) congressolister_bibtex
The dissert_bib function prepares the metadata of the main dissertations to be automatically included in a scientific article. The dissert_bib function internally calls two support functions. The output of the dissert_bib function is the file with the .bib extension, containing the list of dissertation references in BibTex format, prepared to be automatically included in the reference list of a scientific article.
dissert_bib(input_date, input_tam)dissert_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a dissertation |
input_tam |
is the length of the dataframe with the main scientifics dissertation, obtained using package bibliorefer. |
The output of the dissert_bib function is the file with the .bib extension, containing the list of dissertation references in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","dissertacao.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function monograf_bib dissertlister_bibtex <- dissert_bib(input_date, input_tam) dissertlister_bibtex# Example # File of database file_db <- system.file("extdata","dissertacao.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function monograf_bib dissertlister_bibtex <- dissert_bib(input_date, input_tam) dissertlister_bibtex
The example_database function reads a csv file available on the computer system and returns a dataframe as an example of a database to be used by the functions of the bibliorefer package
example_database(path_date, separator)example_database(path_date, separator)
path_date |
is a directory path containing the csv file |
separator |
is the separator for files in csv format |
This function return is a dataframe with database
Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier
#Call the example_database function file_db <- system.file("extdata","example_database.csv", package = "gerefer") separator <- ";" date_sreference <- example_database(file_db, separator) date_sreference#Call the example_database function file_db <- system.file("extdata","example_database.csv", package = "gerefer") separator <- ";" date_sreference <- example_database(file_db, separator) date_sreference
The example_database2 function reads a csv file available on the computer system and returns a dataframe as an example of a database to be used by the functions of the bibliorefer package
example_database2(path_date, separator)example_database2(path_date, separator)
path_date |
is a directory path containing the csv file |
separator |
is the separator for files in csv format |
This function return is a dataframe with database
Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier
#Call the example_database2 function file_db <- system.file("extdata","example_database2.csv", package = "gerefer") separator = ";" date_sreference <- example_database2(file_db, sep = separator) date_sreference#Call the example_database2 function file_db <- system.file("extdata","example_database2.csv", package = "gerefer") separator = ";" date_sreference <- example_database2(file_db, sep = separator) date_sreference
The example_database function reads a csv file available on the computer system and returns a dataframe as an example of a database to be used by the functions of the bibliorefer package
example_databaseart(path_date)example_databaseart(path_date)
path_date |
is a directory path containing the csv file |
This function return is a dataframe with database
Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier
#Call the example_database function file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") date_sreference <- example_databaseart(file_db) date_sreference#Call the example_database function file_db <- system.file("extdata","example_databaseart.csv", package = "gerefer") date_sreference <- example_databaseart(file_db) date_sreference
The jur_bib function prepares the metadata of laws to be automatically included in a scientific article. The jur_bib function internally calls two support functions. The output of the jur_bib function is the file with the .bib extension, of the laws in BibTex format, prepared to be automatically included in the reference list of a scientific article.
jur_bib(input_date, input_tam)jur_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a laws |
input_tam |
is the length of the dataframe with the main scientifics articles, obtained using package bibliorefer. |
The output of the jur_bib function is the file with the .bib extension, of the laws in BibTex format, prepared to be automatically included in the reference list of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","leisemdou.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 3 #Calls the function bookcap_bib jurlister_bibtex <- jur_bib(input_date, input_tam) jurlister_bibtex# Example # File of database file_db <- system.file("extdata","leisemdou.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 3 #Calls the function bookcap_bib jurlister_bibtex <- jur_bib(input_date, input_tam) jurlister_bibtex
The jurdou_bib function prepares the metadata of laws containing DOU to be automatically included in a scientific article. The jurdou_bib function internally calls two support functions. The output of the jurdou_bib function is the file with the .bib extension, of the laws containing DOU in BibTex format, prepared to be automatically included in the scientific reference list.
jurdou_bib(input_date, input_tam)jurdou_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of laws containing DOU |
input_tam |
is the length of the dataframe with the laws containing DOU, obtained using package bibliorefer. |
The output of the jurdou_bib function is the file with the .bib extension, of the laws containing DOU in BibTex format, prepared to be automatically included in the scientific reference list.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example # File of database file_db <- system.file("extdata","leicomdou.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 2 #Calls the function jurdou_bib jurdou_bibtex <- jurdou_bib(input_date, input_tam) jurdou_bibtex# Example # File of database file_db <- system.file("extdata","leicomdou.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 2 #Calls the function jurdou_bib jurdou_bibtex <- jurdou_bib(input_date, input_tam) jurdou_bibtex
The monograf_bib function prepares the metadata of the main monographs to be automatically included in a scientific article. The monograf_bib function internally calls two support functions. The output of the monograf_bib function is the file with the .bib extension, containing the list of monograph references in BibTex format, prepared to be automatically included in the scientific reference list.
monograf_bib(input_date, input_tam)monograf_bib(input_date, input_tam)
input_date |
is a dataframe with the scientific production database in the form of a monograph |
input_tam |
is the length of the dataframe with the main monographs, obtained using package bibliorefer. |
The output of the monograf_bib function is the file with the .bib extension, containing the list of monograph references in BibTex format, prepared to be automatically included in the list of references of a scientific article.
1 - Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier. 2 - Bibliometric indicators to evaluate scientific activity. C García-Villar, J M García-Santos. Radiologia (Engl Ed). 2021 May-Jun;63(3):228-235.
# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","monograf.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function monograf_bib monograflister_bibtex <- monograf_bib(input_date, input_tam) monograflister_bibtex# Example 1 - Concatenated position article # File of database file_db <- system.file("extdata","monograf.csv", package = "gerefer") separator <- ";" # Parameters of the function input_date <- example_database(file_db, separator) input_tam <- 10 #Calls the function monograf_bib monograflister_bibtex <- monograf_bib(input_date, input_tam) monograflister_bibtex